@@ -2,7 +2,7 @@ import logging
 import os
 from collections import defaultdict
 from copy import copy
-from typing import Type
+from typing import TYPE_CHECKING, Dict, Optional, Set, Type
 from urllib.parse import urlparse
 
 from funcy import collecting, project
@@ -24,14 +24,18 @@ from .fs.local import LocalFileSystem
 from .fs.s3 import S3FileSystem
 from .hash_info import HashInfo
 from .istextfile import istextfile
+from .objects import Tree
 from .objects import save as osave
-from .objects.db import NamedCache
 from .objects.errors import ObjectFormatError
 from .objects.stage import stage as ostage
 from .scheme import Schemes
 from .utils import relpath
 from .utils.fs import path_isin
 
+if TYPE_CHECKING:
+    from .objects.db.base import ObjectDB
+    from .objects.file import HashFile
+
 logger = logging.getLogger(__name__)
 
 
@@ -279,9 +283,8 @@ class Output:
     ):
         self.repo = stage.repo if stage else None
 
-        fs_cls, fs_config = get_cloud_fs(self.repo, url=path)
+        fs_cls, fs_config, path_info = get_cloud_fs(self.repo, url=path)
         self.fs = fs_cls(**fs_config)
-        path_info = self.fs.path_info
 
         if (
             self.fs.scheme == "local"
@@ -320,6 +323,8 @@ class Output:
         self.obj = None
         self.isexec = False if self.IS_DEPENDENCY else isexec
 
+        self.def_remote = None
+
     def _parse_path(self, fs, path_info):
         if fs.scheme != "local":
             return path_info
@@ -648,7 +653,7 @@ class Output:
     def download(self, to, jobs=None):
         self.fs.download(self.path_info, to.path_info, jobs=jobs)
 
-    def get_obj(self, filter_info=None):
+    def get_obj(self, filter_info=None, **kwargs):
         if self.obj:
             obj = self.obj
         elif self.hash_info:
@@ -661,7 +666,7 @@ class Output:
 
         if filter_info and filter_info != self.path_info:
             prefix = filter_info.relative_to(self.path_info).parts
-            obj = obj.filter(self.odb, prefix)
+            obj = obj.filter(self.odb, prefix, **kwargs)
 
         return obj
 
@@ -741,9 +746,8 @@ class Output:
         if odb is None:
             odb = self.odb
 
-        cls, config = get_cloud_fs(self.repo, url=source)
+        cls, config, from_info = get_cloud_fs(self.repo, url=source)
         from_fs = cls(**config)
-        from_info = from_fs.path_info
 
         # When running import-url --to-remote / add --to-remote/-o ... we
         # assume that it is unlikely that the odb will contain majority of the
@@ -788,18 +792,14 @@ class Output:
             self.odb.unprotect(self.path_info)
 
     def get_dir_cache(self, **kwargs):
-
         if not self.is_dir_checksum:
             raise DvcException("cannot get dir cache for file checksum")
 
+        obj = self.odb.get(self.hash_info)
         try:
-            objects.check(self.odb, self.odb.get(self.hash_info))
+            objects.check(self.odb, obj)
         except (FileNotFoundError, ObjectFormatError):
-            self.repo.cloud.pull(
-                NamedCache.make("local", self.hash_info.value, str(self)),
-                show_checksums=False,
-                **kwargs,
-            )
+            self.repo.cloud.pull([obj], show_checksums=False, **kwargs)
 
         try:
             self.obj = objects.load(self.odb, self.hash_info)
@@ -810,27 +810,8 @@ class Output:
 
     def collect_used_dir_cache(
         self, remote=None, force=False, jobs=None, filter_info=None
-    ):
-        """Get a list of `info`s related to the given directory.
-
-        - Pull the directory entry from the remote cache if it was changed.
-
-        Example:
-
-            Given the following commands:
-
-            $ echo "foo" > directory/foo
-            $ echo "bar" > directory/bar
-            $ dvc add directory
-
-            It will return a NamedCache like:
-
-            nc = NamedCache()
-            nc.add(self.scheme, 'c157a79031e1', 'directory/foo')
-            nc.add(self.scheme, 'd3b07384d113', 'directory/bar')
-        """
-
-        cache = NamedCache()
+    ) -> Dict[Optional["ObjectDB"], Set["HashFile"]]:
+        """Fetch dir cache and return used objects for this out."""
 
         try:
             self.get_dir_cache(jobs=jobs, remote=remote)
@@ -850,38 +831,22 @@ class Output:
                     "unable to fully collect used cache"
                     " without cache for directory '{}'".format(self)
                 )
-            return cache
+            return {}
 
-        path = str(self.path_info)
-        filter_path = str(filter_info) if filter_info else None
-        for entry_key, entry_obj in self.obj:
-            entry_path = os.path.join(path, *entry_key)
-            if (
-                not filter_path
-                or entry_path == filter_path
-                or entry_path.startswith(filter_path + os.sep)
-            ):
-                cache.add(self.scheme, entry_obj.hash_info.value, entry_path)
+        obj = self.get_obj(filter_info=filter_info, copy=True)
+        self._set_obj_names(obj)
+        return {None: {obj}}
 
-        return cache
-
-    def get_used_cache(self, **kwargs):
-        """Get a dumpd of the given `out`, with an entry including the branch.
-
-        The `used_cache` of an output is no more than its `info`.
-
-        In case that the given output is a directory, it will also
-        include the `info` of its files.
-        """
+    def get_used_objs(
+        self, **kwargs
+    ) -> Dict[Optional["ObjectDB"], Set["HashFile"]]:
+        """Return filtered set of used objects for this out."""
 
         if not self.use_cache:
-            return NamedCache()
+            return {}
 
         if self.stage.is_repo_import:
-            cache = NamedCache()
-            (dep,) = self.stage.deps
-            cache.external[dep.repo_pair].add(dep.def_path)
-            return cache
+            return self.get_used_external(**kwargs)
 
         if not self.hash_info:
             msg = (
@@ -900,18 +865,32 @@ class Output:
                     )
                 )
             logger.warning(msg)
-            return NamedCache()
+            return {}
 
-        ret = NamedCache.make(self.scheme, self.hash_info.value, str(self))
+        if self.is_dir_checksum:
+            return self.collect_used_dir_cache(**kwargs)
 
-        if not self.is_dir_checksum:
-            return ret
+        obj = self.get_obj(filter_info=kwargs.get("filter_info"))
+        if not obj:
+            obj = self.odb.get(self.hash_info)
+        self._set_obj_names(obj)
 
-        ret.add_child_cache(
-            self.hash_info.value, self.collect_used_dir_cache(**kwargs)
-        )
+        return {None: {obj}}
 
-        return ret
+    def _set_obj_names(self, obj):
+        obj.name = str(self)
+        if isinstance(obj, Tree):
+            for key, entry_obj in obj:
+                entry_obj.name = os.path.join(str(self), *key)
+
+    def get_used_external(
+        self, **kwargs
+    ) -> Dict[Optional["ObjectDB"], Set["HashFile"]]:
+        if not self.use_cache or not self.stage.is_repo_import:
+            return {}
+
+        (dep,) = self.stage.deps
+        return dep.get_used_objs()
 
     def _validate_output_path(self, path, stage=None):
         from dvc.dvcfile import is_valid_filename
